@@ -171,35 +171,14 @@ def main():
 
     # Load the configuration (if any)
     uri = options.uri
-    config = {}
-    if uri is None:
-        config = load_config(options.identity)
-
-    # Parse version
-    version = config.get("version")
-    if version is not None:
-        version = parse_version(version)
-        if version is None:
-            print("Unknown version '%s'" % version)
-            return 1
-    else:
-        version = VERSION_LATEST
-    config["version"] = version
-
-    # Parse the command line
-    parser_obj = parser(parser_obj, commands, version)
-    options = parser_obj.parse_args()
-    options.uri = uri
-
-    # Check that a sub_command was given
-    if options.sub_command is None:
-        parser_obj.print_help()
-        return 1
-
-    # Grab the URI if needed
     proxy = None
-    if options.sub_command != "identities":
-        if options.uri is None:
+    version = VERSION_LATEST
+    config = {}
+
+    # Skip when sub_command is "identities"
+    if remaining[0] != "identities":
+        if uri is None:
+            config = load_config(options.identity)
             if config.get("uri") is None:
                 print("Unknown identity '%s'" % options.identity)
                 return 1
@@ -207,25 +186,36 @@ def main():
             token = config.get("token")
             if username is not None and token is not None:
                 p = urlparse(config["uri"])
-                options.uri = "%s://%s:%s@%s%s" % (p.scheme, username, token, p.netloc, p.path)
+                uri = "%s://%s:%s@%s%s" % (p.scheme, username, token, p.netloc, p.path)
             else:
-                options.uri = config["uri"]
+                uri = config["uri"]
 
-        # Create the Transport object
-        parsed_uri = urlparse(options.uri)
-        if options.identity:
+        try:
+            # Create the Transport object
+            parsed_uri = urlparse(uri)
             transport = RequestsTransport(parsed_uri.scheme,
                                           config.get("proxy"),
                                           config.get("timeout", 20.0),
                                           config.get("verify_ssl_cert", True))
-        else:
-            transport = RequestsTransport(parsed_uri.scheme)
-        # allow_none is True because the server does support it
-        proxy = xmlrpc.client.ServerProxy(options.uri, allow_none=True,
-                                          transport=transport)
+            # allow_none is True because the server does support it
+            proxy = xmlrpc.client.ServerProxy(uri, allow_none=True,
+                                              transport=transport)
+            version = proxy.system.version()
+        except (OSError, xmlrpc.client.Error) as exc:
+            print(exc)
+            return 1
+
+        # Parse version
+        version = parse_version(version)
+    config["version"] = version
+
+    # Parse the command line
+    parser_obj = parser(parser_obj, commands, version)
+    options = parser_obj.parse_args()
+    options.uri = uri
 
-    # Connect to the RPC endpoint
     try:
+        # Run the command
         return commands[options.sub_command].handle(proxy, options, config)
     except (ConnectionError, socket.gaierror) as exc:
         print("Unable to connect to '%s': %s" % (options.uri, str(exc)))
