@@ -38,7 +38,7 @@ def configure_parser(parser, version):
     dt_add.add_argument("--owners-only", action="store_true", default=False,
                         help="devices are only visible to owners")
     dt_health = dt_add.add_argument_group("health check")
-    dt_health.add_argument("--health-frequency", default=24,
+    dt_health.add_argument("--health-frequency", default=24, type=int,
                            help="how often to run health checks.")
     dt_health.add_argument("--health-denominator", default="hours",
                            choices=["hours", "jobs"],
@@ -81,7 +81,7 @@ def configure_parser(parser, version):
         dt_set = dt_sub.add_parser("set",
                                    help="set the device-type health-check")
         dt_set.add_argument("name", help="name of the device-type")
-        dt_set.add_argument("template", type=argparse.FileType('r'),
+        dt_set.add_argument("definition", type=argparse.FileType('r'),
                             help="health-check definition")
 
     # "list"
@@ -144,7 +144,7 @@ def configure_parser(parser, version):
                        help="devices are visible to all users")
 
     dt_health = dt_update.add_argument_group("health check")
-    dt_health.add_argument("--health-frequency", default=None,
+    dt_health.add_argument("--health-frequency", default=None, type=int,
                            help="how often to run health checks.")
     dt_health.add_argument("--health-denominator", default=None,
                            choices=["hours", "jobs"],
@@ -168,6 +168,7 @@ def handle_add(proxy, options):
                                      options.display, options.owners_only,
                                      options.health_frequency,
                                      options.health_denominator)
+    return 0
 
 
 def handle_aliases(proxy, options):
@@ -186,14 +187,17 @@ def handle_aliases(proxy, options):
     elif options.sub_sub_sub_command == "delete":
         proxy.scheduler.device_types.aliases.delete(options.name,
                                                     options.alias)
+    return 0
+
 
 def handle_hc(proxy, options):
     if options.sub_sub_sub_command == "get":
         template = proxy.scheduler.device_types.get_health_check(options.name)
         print(str(template).rstrip("\n"))
     else:
-        hc = options.template.read()
+        hc = options.definition.read()
         proxy.scheduler.device_types.set_health_check(options.name, hc)
+    return 0
 
 
 def handle_list(proxy, options):
@@ -207,6 +211,7 @@ def handle_list(proxy, options):
         print("Device-Types:")
         for dt in device_types:
             print("* %s (%s)" % (dt["name"], dt["devices"]))
+    return 0
 
 
 def handle_show(proxy, options):
@@ -224,6 +229,7 @@ def handle_show(proxy, options):
         print("health disabled : %s" % dt["health_disabled"])
         print("aliases         : %s" % dt["aliases"])
         print("devices         : %s" % dt["devices"])
+    return 0
 
 
 def handle_template(proxy, options):
@@ -233,6 +239,7 @@ def handle_template(proxy, options):
     else:
         template = options.template.read()
         proxy.scheduler.device_types.set_template(options.name, template)
+    return 0
 
 
 def handle_update(proxy, options):
@@ -241,6 +248,7 @@ def handle_update(proxy, options):
                                         options.health_frequency,
                                         options.health_denominator,
                                         options.health_disabled)
+    return 0
 
 
 def handle(proxy, options, _):
