@@ -186,6 +186,7 @@ def handle_add(proxy, options, config):
                                     options.group, not options.private,
                                     options.status, options.health,
                                     options.description)
+    return 0
 
 
 def _lookups(value, fields):
@@ -201,6 +202,9 @@ def _lookups(value, fields):
     except KeyError:
         print("Unknow key '%s' for '%s'" % (key, value))
         return 1
+    except TypeError:
+        print("Unable to lookup inside '%s' for '%s'" % (value, key))
+        return 1
     print(value)
     return 0
 
@@ -259,6 +263,7 @@ def handle_list(proxy, options, config):
                 print("* %s (%s): %s,%s" % (device["hostname"], device["type"], device["state"], device["health"]))
             else:
                 print("* %s (%s): %s" % (device["hostname"], device["type"], device["status"]))
+    return 0
 
 
 def handle_maintenance(proxy, options, _):
@@ -275,6 +280,7 @@ def handle_maintenance(proxy, options, _):
         while options.wait and proxy.scheduler.jobs.show(current_job)["state"] != "Finished":
             print("--> waiting")
             time.sleep(5)
+    return 0
 
 
 def handle_show(proxy, options, config):
@@ -294,7 +300,6 @@ def handle_show(proxy, options, config):
             print("status      : %s" % device["status"])
         print("user        : %s" % device["user"])
         print("group       : %s" % device["group"])
-        print("health      : %s" % device["health"])
         print("health job  : %s" % device["health_job"])
         print("description : %s" % device["description"])
         print("public      : %s" % device["public"])
@@ -303,6 +308,7 @@ def handle_show(proxy, options, config):
         print("worker      : %s" % device["worker"])
         print("current job : %s" % device["current_job"])
         print("tags        : %s" % device["tags"])
+    return 0
 
 
 def handle_tags(proxy, options, _):
@@ -320,6 +326,7 @@ def handle_tags(proxy, options, _):
             print("Tags:")
             for tag in tags:
                 print("* %s" % tag)
+    return 0
 
 
 def handle_update(proxy, options, config):
@@ -333,6 +340,7 @@ def handle_update(proxy, options, config):
                                        options.user, options.group,
                                        options.public, options.status,
                                        options.health, options.description)
+    return 0
 
 
 def handle(proxy, options, config):
