@@ -25,7 +25,7 @@ class ConfigurationError(Exception):
     pass
 
 
-def configure_parser(parser, version):
+def configure_parser(parser, _):
     sub = parser.add_subparsers(dest="sub_sub_command", help="Sub commands")
     sub.required = True
 
@@ -46,25 +46,12 @@ def configure_parser(parser, version):
     config_del.add_argument("id", help="identity")
 
     # "list"
-    config_list = sub.add_parser("list", help="list available identities")
+    sub.add_parser("list", help="list available identities")
 
     # "show"
     config_show = sub.add_parser("show", help="show identity details")
     config_show.add_argument("id", type=str, help="identity")
 
-    # "version"
-    config_version = sub.add_parser("version", help="expected version")
-    vers_sub = config_version.add_subparsers(dest="sub_sub_sub_command",
-                                             help="Sub commands")
-    vers_sub.required = True
-    vers_check = vers_sub.add_parser("check",
-                                     help="check version")
-    vers_check.add_argument("id", type=str, help="identity")
-
-    vers_upgrade = vers_sub.add_parser("upgrade",
-                                       help="upgrade to server version")
-    vers_upgrade.add_argument("id", type=str, help="identity")
-
 
 def help_string():
     return "manage lavacli configuration"
@@ -94,7 +81,7 @@ def _save_configuration(config):
         f_conf.write(yaml.dump(config, default_flow_style=False).rstrip("\n"))
 
 
-def handle_add(proxy, options):
+def handle_add(_, options):
     config = _load_configuration()
     config[options.id] = {"uri": options.uri}
     if options.proxy:
@@ -105,61 +92,44 @@ def handle_add(proxy, options):
         config[options.id]["token"] = options.token
 
     _save_configuration(config)
+    return 0
 
 
-def handle_delete(proxy, options):
+def handle_delete(_, options):
     config = _load_configuration()
-    del config[options.id]
+    try:
+        del config[options.id]
+    except KeyError:
+        print("Unknown identity '%s'" % options.id)
+        return 1
     _save_configuration(config)
+    return 0
 
 
-def handle_list(proxy, option):
+def handle_list(_, __):
     config = _load_configuration()
     print("Identities:")
     for identity in sorted(config.keys()):
         print("* %s" % identity)
+    return 0
 
 
-def handle_show(proxy, options):
+def handle_show(_, options):
     config = _load_configuration()
     try:
         conf_str = yaml.dump(config[options.id], default_flow_style=False)
         print(conf_str.rstrip('\n'))
+        return 0
     except KeyError:
         print("Unknown identity '%s'" % options.id)
         return 1
 
 
-def handle_version(proxy, options):
-    if options.sub_sub_sub_command == "check":
-        config = _load_configuration()
-        if config.get(options.id) is None:
-            print("Unknown identity '%s'" % options.id)
-            return 1
-
-        config_version = config[options.id].get("version")
-        server_version = proxy.system.version()
-
-        print("config: %s" % config_version)
-        print("server: %s" % server_version)
-        return config_version != server_version
-    else:
-        config = _load_configuration()
-        if config.get(options.id) is None:
-            print("Unknown identity '%s'" % options.id)
-            return 1
-        version = proxy.system.version()
-        config[options.id]["version"] = version
-        print("server: %s" % version)
-        _save_configuration(config)
-
-
 def handle(proxy, options, _):
     handlers = {
         "add": handle_add,
         "delete": handle_delete,
         "list": handle_list,
         "show": handle_show,
-        "version": handle_version
     }
     return handlers[options.sub_sub_command](proxy, options)
