@@ -18,6 +18,7 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import argparse
+import contextlib
 import datetime
 import json
 import pathlib
@@ -87,6 +88,9 @@ def configure_parser(parser, version):
     # "resubmit"
     jobs_resubmit = sub.add_parser("resubmit", help="resubmit a job")
     jobs_resubmit.add_argument("job_id", help="job id")
+    jobs_resubmit.add_argument("--url", action="store_true",
+                               dest="print_url", default=False,
+                               help="Print the full url")
     jobs_resubmit.add_argument("--filters", default=None, type=str,
                                help="comma seperated list of levels to show")
     jobs_resubmit.add_argument("--follow", default=True, dest="no_follow",
@@ -123,7 +127,7 @@ def configure_parser(parser, version):
 
     # "submit"
     jobs_submit = sub.add_parser("submit", help="submit a new job")
-    jobs_submit.add_argument("definition", type=argparse.FileType('r'),
+    jobs_submit.add_argument("definition", nargs="+", type=argparse.FileType('r'),
                              help="job definition")
     jobs_submit.add_argument("--url", action="store_true",
                              dest="print_url", default=False,
@@ -143,6 +147,7 @@ def help_string():
 
 def handle_cancel(proxy, options, _):
     proxy.scheduler.jobs.cancel(options.job_id)
+    return 0
 
 
 def handle_config(proxy, options, _):
@@ -151,27 +156,30 @@ def handle_config(proxy, options, _):
 
     # Create the directory if needed
     dest = pathlib.Path(options.dest)
-    dest.mkdir(mode=0o755, exist_ok=True)
+    with contextlib.suppress(FileExistsError):
+        dest.mkdir(mode=0o755)
 
     # Save the files
-    with open(dest / "definition.yaml", "w") as f_out:
+    with open(str(dest / "definition.yaml"), "w") as f_out:
         f_out.write(definition)
     if device is not None:
-        with open(dest / "device.yaml", "w") as f_out:
+        with open(str(dest / "device.yaml"), "w") as f_out:
             f_out.write(device)
     if dispatcher is not None:
-        with open(dest / "dispatcher.yaml", "w") as f_out:
+        with open(str(dest / "dispatcher.yaml"), "w") as f_out:
             f_out.write(dispatcher)
     if env is not None:
-        with open(dest / "env.yaml", "w") as f_out:
+        with open(str(dest / "env.yaml"), "w") as f_out:
             f_out.write(env)
     if env_dut is not None:
-        with open(dest / "env.dut.yaml", "w") as f_out:
+        with open(str(dest / "env.dut.yaml"), "w") as f_out:
             f_out.write(env_dut)
+    return 0
 
 
 def handle_definition(proxy, options, _):
     print(proxy.scheduler.jobs.definition(options.job_id))
+    return 0
 
 
 def handle_list(proxy, options, config):
@@ -195,6 +203,7 @@ def handle_list(proxy, options, config):
                 print("* %s: %s [%s] (%s) - %s" % (job["id"], job["status"],
                                                    job["submitter"], job["description"],
                                                    job["device_type"]))
+    return 0
 
 
 if sys.stdout.isatty():
@@ -276,17 +285,24 @@ def handle_logs(proxy, options, _):
                          "lvl": "info",
                          "msg": "[lavacli] Failure comment: %s" % details["failure_comment"]}],
                        options.raw, options.filters)
+    return 0
 
 
 def handle_resubmit(proxy, options, config):
     job_id = proxy.scheduler.jobs.resubmit(options.job_id)
 
     if options.no_follow:
+        prefix = ""
+        if options.print_url:
+            parsed = urlparse(options.uri)
+            host = parsed.netloc.split("@")[-1]
+            prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
+
         if isinstance(job_id, list):
             for job in job_id:
-                print(job)
+                print(prefix + str(job))
         else:
-            print(job_id)
+            print(prefix + str(job_id))
 
     else:
         print_logs([{"dt": datetime.datetime.utcnow().isoformat(),
@@ -305,8 +321,9 @@ def handle_resubmit(proxy, options, config):
                 options.job_id = job
                 handle_logs(proxy, options, config)
         else:
-            options.job_id = job_id
+            options.job_id = str(job_id)
             handle_logs(proxy, options, config)
+    return 0
 
 
 def handle_run(proxy, options, config):
@@ -329,6 +346,7 @@ def handle_run(proxy, options, config):
     else:
         options.job_id = job_id
         handle_logs(proxy, options, config)
+    return 0
 
 
 def handle_show(proxy, options, config):
@@ -364,22 +382,25 @@ def handle_show(proxy, options, config):
         print("submit time : %s" % job["submit_time"])
         print("start time  : %s" % job["start_time"])
         print("end time    : %s" % job["end_time"])
+    return 0
 
 
 def handle_submit(proxy, options, _):
-    job_id = proxy.scheduler.jobs.submit(options.definition.read())
+    for definition in options.definition:
+        job_id = proxy.scheduler.jobs.submit(definition.read())
 
-    prefix = ""
-    if options.print_url:
-        parsed = urlparse(options.uri)
-        host = parsed.netloc.split("@")[-1]
-        prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
+        prefix = ""
+        if options.print_url:
+            parsed = urlparse(options.uri)
+            host = parsed.netloc.split("@")[-1]
+            prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
 
-    if isinstance(job_id, list):
-        for job in job_id:
-            print(prefix + str(job))
-    else:
-        print(prefix + str(job_id))
+        if isinstance(job_id, list):
+            for job in job_id:
+                print(prefix + str(job))
+        else:
+            print(prefix + str(job_id))
+    return 0
 
 
 def handle_wait(proxy, options, _):
@@ -396,6 +417,9 @@ def handle_wait(proxy, options, _):
         old_state = job["state"]
         time.sleep(options.polling)
         job = proxy.scheduler.jobs.show(options.job_id)
+    if old_state != job["state"] and old_state:
+        sys.stdout.write("\n")
+    return 0
 
 
 def handle(proxy, options, config):
